#!/usr/bin/env python

"""
cmd1:env keystore=`pwd` ./query.py 
cmd2: env ABAC_CN=1 keystore=`pwd` ./query.py

"""

import os
import ABAC

ctxt = ABAC.Context()

# Keystore is the directory containing the principal credentials.
# Load existing principals and/or policy credentials
if (os.environ.has_key("keystore")) :
    keystore=os.environ["keystore"]
    ctxt.load_directory(keystore)
else:
    print("keystore is not set...")
    exit(1)

# retrieve principals' keyid value from local credential files
acmeID=ABAC.ID("Acme_ID.pem");
acme=acmeID.id_keyid()

oshID=ABAC.ID("Osh_ID.pem");
osh=oshID.id_keyid()

coyoteID=ABAC.ID("Coyote_ID.pem");
coyote=coyoteID.id_keyid()

ladybugID=ABAC.ID("Ladybug_ID.pem");
ladybug=ladybugID.id_keyid()

##########################################################################
# dump the loaded principals/policies
#
out = ctxt.context_principals()
print "\n...final principal set..."
for x in out[1]:
    print "%s " % x.string()
out = ctxt.context_credentials()
print "\n...final policy attribute set..."
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())

##########################################################################
# can coyote buy rockets from Acme ?
# role=[keyid:Acme].role:buy_rockets
# p =[keyid:coyote]
role = ABAC.Role(acme,"buy_rockets")
p = ABAC.Role(coyote)
print "\n===good============ Acme.buy_rockets <- Coyote"
out = ctxt.query(role, p)
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())

##########################################################################
# can ladybug buy rockets from Acme ?
# role=[keyid:Acme].role:buy_rockets
# p =[keyid:ladybug]
role = ABAC.Role(acme,"buy_rockets")
p = ABAC.Role(ladybug)
print "\n===bad============ Acme.buy_rockets <- Ladybug"
out = ctxt.query(role, p)
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())

##########################################################################
# can ladybug buy rockets from Osh ?
# role=[keyid:Osh].role:buy_rockets
# p =[keyid:ladybug]
role = ABAC.Role(osh,"buy_rockets")
p = ABAC.Role(ladybug)
print "\n===good============ Osh.buy_rockets <- Ladybug"
out = ctxt.query(role, p)
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())


